#!/usr/bin/gawk -f

BEGIN{
  cm = 1.e-2;	# m
  mu = 1.e-6;	# m
  nm = 1.e-9;	# m
  Ang = 1.e-10;	# m
  erg = 1.e-7;	# J

  calibration_flux = 0.036895;  # [J s^-1 m^-2 m^-1]; used for V band

  lambda1 = 321.*nm;	# i.e. the range of synthetic spectra we have at disposal 
  lambda2 = 100000.*nm;

  d_pc = 381.;
  EB_minus_V = 0.042;
  k = 3.1;
  A_V = k*EB_minus_V;

  n=0;
}
(ARGIND==1) && !/^#/{
  n++;
  lambda[n] = $1*mu;
  A_lambda_A_V[n] = $2+0.0;
}
(ARGIND>1) && (FNR==1){
  print $0;
  print "# d_pc = ", d_pc, " pc";
  print "# E(B-V) = ", EB_minus_V, " mag";
  print "# k = A_V/E(B-V) = ", k;
  print "# A_V = ", A_V, " mag";
}
(ARGIND>1) && (FNR>1) && (NF==0){
  print;
}
(ARGIND>1) && /^#/{
  print;
}
(ARGIND>1) && (FNR>1) && (NF>0) && !/^#/{
  lambda_eff = $1;
  band_eff = $2;
  mag = $3;
  sigma = $4;
  calibration_flux = $5;
  filter = $6;

#  mag = -2.5*log10(flux/calibration_flux);
#  mag_sigma = 0.01;

  A_lambda_A_V_ = linterp(lambda, A_lambda_A_V, n, lambda_eff, extra);
  A_lambda = A_lambda_A_V_ * A_V;

  mag0 = mag - A_lambda;

#  if ((lambda_eff-band_eff/2.0 >= lambda1) && (lambda_eff+band_eff/2.0 <= lambda2)) {
    printf("%10.4e  %10.4e  %10.4f  %10.4f  %10.6e  %s\n", lambda_eff, band_eff, mag0, sigma, calibration_flux, filter);
#  }
}

function log10(x) {
  return log(x)/log(10);
}

func linterp(x,y,n,x0,extra, i,y0) {
 
  if (x0 < x[1]) {
    extra = 1;
    i = 2;
  } else if (x0 > x[n]) {
    extra = 1;
    i = n
  } else {
    extra = 0;
    i = 2
    while (x[i] < x0) {
      i++;
    }
  }

  if (x[i]==x[i-1]) {
    y0 = y[i];
  } else {
    y0 = y[i-1] + (y[i]-y[i-1]) * (x0-x[i-1])/(x[i]-x[i-1]);
  }

#  print x0,"i = ",i,x[i-1],x[i],y[i-1],y[i],y0;	# dbg

  if (extra == 1) {
    print "# Warning: Extrapolation for x0 = ", x0;
  }

  return y0;
}


